LiquidGlassDatePicker class

A native SwiftUI DatePicker with Liquid Glass styling on iOS 26+.

On non-iOS platforms it falls back to a button that opens Flutter's showDatePicker.

Inheritance

Constructors

LiquidGlassDatePicker({Key? key, required DateTime value, required ValueChanged<DateTime> onChanged, DateTime? min, DateTime? max, String? mode})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
max DateTime?
final
min DateTime?
final
mode String?
The display mode: 'date', 'time', or 'dateAndTime'. Defaults to 'date' on the native side.
final
onChanged ValueChanged<DateTime>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value DateTime
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<LiquidGlassDatePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited